@@ -1,8 +1,9 @@
 import re
+import sys
 from typing import Any, Iterable, Optional, Tuple, Type, Union, cast
 from urllib import parse as urlparse
 
-import pkg_resources
+import django
 from django import forms
 from django.contrib.admin.filters import FieldListFilter
 from django.core import checks, exceptions
@@ -15,10 +16,24 @@ from django.utils.html import escape as escape_html
 from django_countries import Countries, countries, filters, ioc_data, widgets
 from django_countries.conf import settings
 
-EXTENSIONS = {
-    ep.name: ep.load()
-    for ep in pkg_resources.iter_entry_points("django_countries.Country")
-}
+_entry_points: Iterable[Any]
+try:
+    import importlib.metadata
+
+    if sys.version_info >= (3, 10):
+        _entry_points = importlib.metadata.entry_points(
+            group="django_countries.Country"
+        )
+    else:
+        _entry_points = importlib.metadata.entry_points().get(
+            "django_countries.Country", []
+        )
+except ImportError:  # Python <3.8
+    import pkg_resources
+
+    _entry_points = pkg_resources.iter_entry_points("django_countries.Country")
+
+EXTENSIONS = {ep.name: ep.load() for ep in _entry_points}  # type: ignore
 
 
 class TemporaryEscape:
@@ -221,12 +236,14 @@ class CountryDescriptor:
 
 
 class LazyChoicesMixin(widgets.LazyChoicesMixin):
-    def _set_choices(self, value):
-        """
-        Also update the widget's choices.
-        """
-        super()._set_choices(value)
-        self.widget.choices = value
+    if django.VERSION < (5, 0):
+
+        def _set_choices(self, value):
+            """
+            Also update the widget's choices.
+            """
+            super()._set_choices(value)
+            self.widget.choices = value
 
 
 _Choice = Tuple[Any, str]
@@ -259,6 +276,7 @@ class CountryField(CharField):
     """
 
     descriptor_class = CountryDescriptor
+    countries: Countries
 
     def __init__(self, *args: Any, **kwargs: Any):
         countries_class: Type[Countries] = kwargs.pop("countries", None)
@@ -267,7 +285,13 @@ class CountryField(CharField):
         self.countries_str_attr = kwargs.pop("countries_str_attr", "code")
         self.blank_label = kwargs.pop("blank_label", None)
         self.multiple = kwargs.pop("multiple", None)
-        kwargs["choices"] = self.countries
+        self.multiple_unique = kwargs.pop("multiple_unique", True)
+        self.multiple_sort = kwargs.pop("multiple_sort", True)
+        if django.VERSION >= (5, 0):
+            # Use new lazy callable support
+            kwargs["choices"] = lambda: self.countries
+        else:
+            kwargs["choices"] = self.countries
         if "max_length" not in kwargs:
             # Allow explicit max_length so migrations can correctly identify
             # changes in the multiple CountryField fields when new countries are
@@ -348,8 +372,20 @@ class CountryField(CharField):
                 iter(value)
             except TypeError:
                 value = [value]
-        # Remove duplicates and False-y values, sort.
-        return sorted(set(filter(None, (self.country_to_text(c) for c in value))))
+        cleaned_value = []
+        seen = set()
+        for c in value:
+            c = self.country_to_text(c)
+            if not c:
+                continue
+            if self.multiple_unique:
+                if c in seen:
+                    continue
+                seen.add(c)
+            cleaned_value.append(c)
+        if self.multiple_sort:
+            cleaned_value = sorted(cleaned_value)
+        return cleaned_value
 
     def deconstruct(self):
         """
@@ -363,25 +399,55 @@ class CountryField(CharField):
         kwargs.pop("choices", None)
         if self.multiple:  # multiple determines the length of the field
             kwargs["multiple"] = self.multiple
+        if not self.multiple_unique:
+            kwargs["multiple_unique"] = False
+        if not self.multiple_sort:
+            kwargs["multiple_sort"] = False
         if self.countries is not countries:
             # Include the countries class if it's not the default countries
             # instance.
             kwargs["countries"] = self.countries.__class__
         return name, path, args, kwargs
 
-    def get_choices(self, include_blank=True, blank_choice=None, *args, **kwargs):
-        if blank_choice is None:
+    if django.VERSION >= (5, 0):
+
+        def get_choices(
+            self,
+            include_blank=True,
+            blank_choice=BLANK_CHOICE_DASH,
+            limit_choices_to=None,
+            ordering=(),
+        ):
+            if self.multiple:
+                include_blank = False
             if self.blank_label is None:
                 blank_choice = BLANK_CHOICE_DASH
             else:
                 blank_choice = [("", self.blank_label)]
-        if self.multiple:
-            include_blank = False
-        return super().get_choices(
-            include_blank=include_blank, blank_choice=blank_choice, *args, **kwargs
-        )
+            return super().get_choices(
+                include_blank=include_blank,
+                blank_choice=blank_choice,
+                limit_choices_to=limit_choices_to,
+                ordering=ordering,
+            )
 
-    get_choices = lazy(get_choices, list)
+    else:
+
+        def get_choices(  # type: ignore [misc]
+            self, include_blank=True, blank_choice=None, *args, **kwargs
+        ):
+            if blank_choice is None:
+                if self.blank_label is None:
+                    blank_choice = BLANK_CHOICE_DASH
+                else:
+                    blank_choice = [("", self.blank_label)]
+            if self.multiple:
+                include_blank = False
+            return super().get_choices(
+                include_blank=include_blank, blank_choice=blank_choice, *args, **kwargs
+            )
+
+        get_choices = lazy(get_choices, list)
 
     def formfield(self, **kwargs):
         kwargs.setdefault(
@@ -482,10 +548,15 @@ class FullNameLookup(lookups.In):
             value = self.expr.format(
                 text=re.escape(self.rhs) if self.escape_regex else self.rhs
             )
-            return cast(CountryField, self.lhs.output_field).countries.by_name(
+            options = cast(CountryField, self.lhs.output_field).countries.by_name(
                 value, regex=True, insensitive=self.insensitive
             )
-        return super().get_prep_lookup()
+            if len(self.rhs) == 2 and (
+                self.rhs == self.rhs.upper() or self.insensitive
+            ):
+                options.add(self.rhs.upper())
+            return options
+        return super().get_prep_lookup()  # pragma: no cover
 
 
 @CountryField.register_lookup
