@@ -4,6 +4,7 @@ from unittest import mock
 from unittest.case import skipUnless
 
 import django
+import pytest
 from django.core import checks, validators
 from django.core.management import call_command
 from django.db import models
@@ -14,6 +15,7 @@ from django.utils import translation
 from django.utils.encoding import force_str
 
 from django_countries import countries, data, fields
+from django_countries.conf import settings
 from django_countries.fields import CountryField
 from django_countries.tests import custom_countries, forms
 from django_countries.tests.models import AllowNull, MultiCountry, Person, WithProp
@@ -246,9 +248,10 @@ class TestCountryField(TestCase):
         self.assertEqual(list(Person.objects.filter(country__contains="ew")), [p, pp])
         self.assertEqual(list(Person.objects.filter(country__contains="EW")), [])
         self.assertEqual(list(Person.objects.filter(country__icontains="EW")), [p, pp])
-        # No longer works with codes.
-        self.assertEqual(list(Person.objects.filter(country__contains="NZ")), [])
-        self.assertEqual(list(Person.objects.filter(country__icontains="nz")), [])
+        # Also works with country codes.
+        self.assertEqual(list(Person.objects.filter(country__contains="NZ")), [p])
+        self.assertEqual(list(Person.objects.filter(country__contains="nz")), [])
+        self.assertEqual(list(Person.objects.filter(country__icontains="nz")), [p])
 
     def test_by_country_name_startswith(self):
         p = Person.objects.create(name="A", country="ZA")  # South Africa
@@ -259,9 +262,10 @@ class TestCountryField(TestCase):
         self.assertEqual(list(Person.objects.filter(country__startswith="South")), [p])
         self.assertEqual(list(Person.objects.filter(country__startswith="south")), [])
         self.assertEqual(list(Person.objects.filter(country__istartswith="south")), [p])
-        # No longer works with codes.
-        self.assertEqual(list(Person.objects.filter(country__startswith="ZA")), [])
-        self.assertEqual(list(Person.objects.filter(country__istartswith="za")), [])
+        # Also works with country codes.
+        self.assertEqual(list(Person.objects.filter(country__startswith="ZA")), [p])
+        self.assertEqual(list(Person.objects.filter(country__startswith="za")), [])
+        self.assertEqual(list(Person.objects.filter(country__istartswith="za")), [p])
 
     def test_by_country_name_endswith(self):
         p = Person.objects.create(name="A", country="AS")  # American Samoa
@@ -274,9 +278,10 @@ class TestCountryField(TestCase):
         self.assertEqual(
             list(Person.objects.filter(country__iendswith="america")), [pp]
         )
-        # No longer works with codes.
-        self.assertEqual(list(Person.objects.filter(country__endswith="US")), [])
-        self.assertEqual(list(Person.objects.filter(country__iendswith="us")), [])
+        # Also works with country codes.
+        self.assertEqual(list(Person.objects.filter(country__endswith="US")), [pp])
+        self.assertEqual(list(Person.objects.filter(country__endswith="us")), [])
+        self.assertEqual(list(Person.objects.filter(country__iendswith="us")), [pp])
 
     def test_by_country_name_regex(self):
         p = Person.objects.create(name="A", country="MK")  # North Macedonia
@@ -285,9 +290,10 @@ class TestCountryField(TestCase):
         self.assertEqual(list(Person.objects.filter(country__regex=r"North\b")), [p])
         self.assertEqual(list(Person.objects.filter(country__regex=r"north\b")), [])
         self.assertEqual(list(Person.objects.filter(country__iregex=r"north\b")), [p])
-        # No longer works with codes.
-        self.assertEqual(list(Person.objects.filter(country__regex="MP")), [])
-        self.assertEqual(list(Person.objects.filter(country__iregex="mp")), [])
+        # Also works with country codes.
+        self.assertEqual(list(Person.objects.filter(country__regex="MP")), [pp])
+        self.assertEqual(list(Person.objects.filter(country__regex="mp")), [])
+        self.assertEqual(list(Person.objects.filter(country__iregex="mp")), [pp])
 
 
 class TestValidation(TestCase):
@@ -424,10 +430,19 @@ class TestCountryMultiple(TestCase):
         self.assertEqual(obj.countries[1], "NZ")
 
     def test_multiple_with_duplicates(self):
-        obj = MultiCountry(countries="AU,NZ,AU")
+        codes = "NZ,AU,NZ"
+        obj = MultiCountry(
+            countries=codes,
+            unsorted_countries=codes,
+            duplicate_countries=codes,
+            unsorted_duplicate_countries=codes,
+        )
         for country in obj.countries:
             self.assertTrue(isinstance(country, fields.Country))
         self.assertEqual(obj.countries, ["AU", "NZ"])
+        self.assertEqual(obj.unsorted_countries, ["NZ", "AU"])
+        self.assertEqual(obj.duplicate_countries, ["AU", "NZ", "NZ"])
+        self.assertEqual(obj.unsorted_duplicate_countries, ["NZ", "AU", "NZ"])
 
         obj = MultiCountry(countries="")
         self.assertEqual(obj.countries, [])
@@ -579,6 +594,7 @@ class TestCountryObject(TestCase):
 
 
 class TestModelForm(TestCase):
+    @pytest.mark.skipif(not settings.USE_I18N, reason="No i18n")
     def test_translated_choices(self):
         lang = translation.get_language()
         translation.activate("eo")
